Examples directory
==================

This directory contains example scripts.

It is outside the `ctapipe` package and thus will not be installed with it
and can't be imported, i.e. what's here is not re-usable from other parts
of `ctapipe` or scripts.
